@@ -36,10 +36,12 @@ void MessageComposer::init()
 
 #if defined(Q_WS_MAEMO_5) || defined(MEEGO_EDITION_HARMATTAN)
     ui->textBrowser->setMaximumHeight(0);
+    ui->textBrowser->setMaximumWidth(0);
     ui->textBrowser->setEnabled(false);
     ui->verticalLayout->addWidget(textLabel = new QTextEdit(this), 0, Qt::AlignCenter);
     textLabel->setStyleSheet("QTextEdit {background-color: white;}");
     textLabel->setMinimumHeight(195);
+    textLabel->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
 #endif
 
     connect(buttonSend, SIGNAL(clicked()), this, SLOT(sendMessage()));
@@ -86,7 +88,11 @@ void MessageComposer::updateFriendList(FriendList list, bool )
 void MessageComposer::sendMessage()
 {
     QString title = this->ui->titleLineEdit->text();
+#if defined(Q_WS_MAEMO_5) || defined(MEEGO_EDITION_HARMATTAN)
+    QString message = textLabel->toPlainText();
+#else
     QString message = this->ui->textBrowser->toPlainText();
+#endif
 
     int index = ui->listFriends->currentIndex();
     QVariant v = ui->listFriends->itemData(index);
@@ -116,7 +122,11 @@ void MessageComposer::replyMessage(Message msg)
     }
 
     this->ui->titleLineEdit->setText(QString(tr("Re: %1")).arg(msg.subject()));
+#if defined(Q_WS_MAEMO_5) || defined(MEEGO_EDITION_HARMATTAN)
+    textLabel->setFocus();
+#else
     this->ui->textBrowser->setFocus();
+#endif
 }
 
 void MessageComposer::saveMessage()
@@ -134,7 +144,11 @@ void MessageComposer::saveMessage()
     }
 
     QString title = this->ui->titleLineEdit->text();
+#if defined(Q_WS_MAEMO_5) || defined(MEEGO_EDITION_HARMATTAN)
+    QString message = this->textLabel->toPlainText();
+#else
     QString message = this->ui->textBrowser->toPlainText();
+#endif
 
     Message msg;
     msg.setAccountId(senderId);
@@ -172,7 +186,11 @@ void MessageComposer::saveMessage()
 void MessageComposer::resetMessage()
 {
     this->ui->titleLineEdit->clear();
+#if defined(Q_WS_MAEMO_5) || defined(MEEGO_EDITION_HARMATTAN)
+    this->textLabel->clear();
+#else
     this->ui->textBrowser->clear();
+#endif
 }
 
 void MessageComposer::setRecepient(Friend fd)
@@ -202,5 +220,9 @@ void MessageComposer::setTitle(QString title)
 
 void MessageComposer::setMessageBody(QString text)
 {
+#if defined(Q_WS_MAEMO_5) || defined(MEEGO_EDITION_HARMATTAN)
+    this->textLabel->setText(text);
+#else
     this->ui->textBrowser->setText(text);
+#endif
 }
