@@ -40,6 +40,14 @@
         <translation>Обновлен:</translation>
     </message>
 </context>
+<context>
+    <name>AlbumSelectDialog</name>
+    <message>
+        <location filename="../src/widgets/albumselectdialog.ui" line="14"/>
+        <source>Select album</source>
+        <translation>Выбор альбома</translation>
+    </message>
+</context>
 <context>
     <name>FilterFriendGender</name>
     <message>
@@ -103,8 +111,8 @@
         <translation type="obsolete">Друзья</translation>
     </message>
     <message>
-        <location filename="../src/panels/imagebrowserpanel.cpp" line="103"/>
-        <location filename="../src/panels/imagebrowserpanel.cpp" line="442"/>
+        <location filename="../src/panels/imagebrowserpanel.cpp" line="113"/>
+        <location filename="../src/panels/imagebrowserpanel.cpp" line="451"/>
         <source>People (%1)</source>
         <translation>Друзья (%1)</translation>
     </message>
@@ -121,7 +129,7 @@
         <translation type="obsolete">Введите имя...</translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/panels/imagebrowserpanel.cpp" line="287"/>
+        <location filename="../src/panels/imagebrowserpanel.cpp" line="296"/>
         <source>%1 photo(s)</source>
         <translation>
             <numerusform>%1 изображение</numerusform>
@@ -130,22 +138,22 @@
         </translation>
     </message>
     <message>
-        <location filename="../src/panels/imagebrowserpanel.cpp" line="289"/>
+        <location filename="../src/panels/imagebrowserpanel.cpp" line="298"/>
         <source> Updated: </source>
         <translation> Обновлен: </translation>
     </message>
     <message>
-        <location filename="../src/panels/imagebrowserpanel.cpp" line="316"/>
+        <location filename="../src/panels/imagebrowserpanel.cpp" line="325"/>
         <source>Album(s):</source>
         <translation>Альбом(ы):</translation>
     </message>
     <message>
-        <location filename="../src/panels/imagebrowserpanel.cpp" line="389"/>
+        <location filename="../src/panels/imagebrowserpanel.cpp" line="398"/>
         <source>Photo(s):</source>
         <translation>Изображения:</translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/panels/imagebrowserpanel.cpp" line="400"/>
+        <location filename="../src/panels/imagebrowserpanel.cpp" line="409"/>
         <source>%1 photo(s):</source>
         <translation>
             <numerusform>%1 изображение:</numerusform>
@@ -166,39 +174,39 @@
         <translation type="obsolete">В сети</translation>
     </message>
     <message>
-        <location filename="../src/panels/imagebrowserpanel.cpp" line="282"/>
+        <location filename="../src/panels/imagebrowserpanel.cpp" line="291"/>
         <source>Untitled album</source>
         <translation>Безымянный альбом</translation>
     </message>
     <message>
-        <location filename="../src/panels/imagebrowserpanel.cpp" line="492"/>
-        <location filename="../src/panels/imagebrowserpanel.cpp" line="954"/>
+        <location filename="../src/panels/imagebrowserpanel.cpp" line="501"/>
+        <location filename="../src/panels/imagebrowserpanel.cpp" line="963"/>
         <source>No albums</source>
         <translation>Нет альбомов</translation>
     </message>
     <message>
-        <location filename="../src/panels/imagebrowserpanel.cpp" line="494"/>
-        <location filename="../src/panels/imagebrowserpanel.cpp" line="952"/>
+        <location filename="../src/panels/imagebrowserpanel.cpp" line="503"/>
+        <location filename="../src/panels/imagebrowserpanel.cpp" line="961"/>
         <source>Download albums</source>
         <translation>Загрузка альбомов</translation>
     </message>
     <message>
-        <location filename="../src/panels/imagebrowserpanel.cpp" line="612"/>
+        <location filename="../src/panels/imagebrowserpanel.cpp" line="621"/>
         <source>No images</source>
         <translation>Нет изображений</translation>
     </message>
     <message>
-        <location filename="../src/panels/imagebrowserpanel.cpp" line="614"/>
+        <location filename="../src/panels/imagebrowserpanel.cpp" line="623"/>
         <source>Download images</source>
         <translation>Загрузка изображений</translation>
     </message>
     <message>
-        <location filename="../src/panels/imagebrowserpanel.cpp" line="892"/>
+        <location filename="../src/panels/imagebrowserpanel.cpp" line="901"/>
         <source>Error occured</source>
         <translation>Произошла ошибка</translation>
     </message>
     <message>
-        <location filename="../src/panels/imagebrowserpanel.cpp" line="892"/>
+        <location filename="../src/panels/imagebrowserpanel.cpp" line="901"/>
         <source>Unknown window state</source>
         <translation>Неопределенное состояние окна</translation>
     </message>
@@ -264,7 +272,7 @@
     </message>
     <message>
         <location filename="../src/panels/messagebrowserpanel.cpp" line="63"/>
-        <location filename="../src/panels/messagebrowserpanel.cpp" line="173"/>
+        <location filename="../src/panels/messagebrowserpanel.cpp" line="434"/>
         <source>Messages (%1)</source>
         <translation>Сообщения (%1)</translation>
     </message>
@@ -277,12 +285,12 @@
         <translation type="obsolete">Обновления (%1)</translation>
     </message>
     <message>
-        <location filename="../src/panels/messagebrowserpanel.cpp" line="362"/>
+        <location filename="../src/panels/messagebrowserpanel.cpp" line="364"/>
         <source>Error occured</source>
         <translation>Произошла ошибка</translation>
     </message>
     <message>
-        <location filename="../src/panels/messagebrowserpanel.cpp" line="362"/>
+        <location filename="../src/panels/messagebrowserpanel.cpp" line="364"/>
         <source>Unknown window state</source>
         <translation>Неопределенное состояние окна</translation>
     </message>
@@ -323,11 +331,24 @@
 <context>
     <name>NewsBrowserPanel</name>
     <message>
-        <location filename="../src/panels/newsbrowserpanel.cpp" line="173"/>
+        <location filename="../src/panels/newsbrowserpanel.cpp" line="174"/>
         <source>News (%1)</source>
         <translation>Новости (%1)</translation>
     </message>
 </context>
+<context>
+    <name>PhotoListWidget</name>
+    <message>
+        <location filename="../src/widgets/photolistwidget.cpp" line="97"/>
+        <source>Copy to</source>
+        <translation>Копировать в</translation>
+    </message>
+    <message>
+        <location filename="../src/widgets/photolistwidget.cpp" line="116"/>
+        <source>Select...</source>
+        <translation>Выбрать...</translation>
+    </message>
+</context>
 <context>
     <name>ProfileBrowser</name>
     <message>
@@ -413,6 +434,11 @@
     </message>
     <message>
         <location filename="../src/widgets/profilebrowser.cpp" line="142"/>
+        <source>Status</source>
+        <translation>Статус</translation>
+    </message>
+    <message>
+        <location filename="../src/widgets/profilebrowser.cpp" line="148"/>
         <source>Contacts</source>
         <translation>Контакты</translation>
     </message>
@@ -435,17 +461,17 @@
         <translation>Форма</translation>
     </message>
     <message>
-        <location filename="../src/panels/profilebrowserpanel.cpp" line="74"/>
+        <location filename="../src/panels/profilebrowserpanel.cpp" line="76"/>
         <source>Albums</source>
         <translation>Альбомы</translation>
     </message>
     <message>
-        <location filename="../src/panels/profilebrowserpanel.cpp" line="84"/>
+        <location filename="../src/panels/profilebrowserpanel.cpp" line="88"/>
         <source>Messages</source>
         <translation>Сообщения</translation>
     </message>
     <message>
-        <location filename="../src/panels/profilebrowserpanel.cpp" line="94"/>
+        <location filename="../src/panels/profilebrowserpanel.cpp" line="100"/>
         <source>Send message</source>
         <translation>Новое</translation>
     </message>
@@ -458,8 +484,8 @@
         <translation type="obsolete">Друзья</translation>
     </message>
     <message>
-        <location filename="../src/panels/profilebrowserpanel.cpp" line="61"/>
-        <location filename="../src/panels/profilebrowserpanel.cpp" line="211"/>
+        <location filename="../src/panels/profilebrowserpanel.cpp" line="62"/>
+        <location filename="../src/panels/profilebrowserpanel.cpp" line="231"/>
         <source>People (%1)</source>
         <translation>Друзья (%1)</translation>
     </message>
@@ -480,12 +506,12 @@
         <translation type="obsolete">Загрузка списка друзей</translation>
     </message>
     <message>
-        <location filename="../src/panels/profilebrowserpanel.cpp" line="284"/>
+        <location filename="../src/panels/profilebrowserpanel.cpp" line="304"/>
         <source>Error occured</source>
         <translation>Произошла ошибка</translation>
     </message>
     <message>
-        <location filename="../src/panels/profilebrowserpanel.cpp" line="284"/>
+        <location filename="../src/panels/profilebrowserpanel.cpp" line="304"/>
         <source>Unknown window state</source>
         <translation>Неопределенное состояние окна</translation>
     </message>
@@ -522,12 +548,12 @@
         <translation>Форма</translation>
     </message>
     <message>
-        <location filename="../src/widgets/friends/qfriendlistwidget.cpp" line="24"/>
+        <location filename="../src/widgets/friends/qfriendlistwidget.cpp" line="25"/>
         <source>Type a name...</source>
         <translation>Введите имя...</translation>
     </message>
     <message>
-        <location filename="../src/widgets/friends/qfriendlistwidget.cpp" line="60"/>
+        <location filename="../src/widgets/friends/qfriendlistwidget.cpp" line="63"/>
         <source>Me</source>
         <translation>Мое</translation>
     </message>
@@ -595,7 +621,7 @@
         <translation type="obsolete">Введите имя...</translation>
     </message>
     <message>
-        <location filename="../src/widgets/messages/qmessagelistwidget.cpp" line="25"/>
+        <location filename="../src/widgets/messages/qmessagelistwidget.cpp" line="26"/>
         <source>Type a title...</source>
         <translation>Введите тему сообщения...</translation>
     </message>
@@ -802,9 +828,13 @@
         <translation>Число ошибок</translation>
     </message>
     <message>
-        <location filename="../src/widgets/qstatwidget.ui" line="14"/>
         <source>VKGallery - Help</source>
-        <translation>VKGallery - Справка</translation>
+        <translation type="obsolete">VKGallery - Справка</translation>
+    </message>
+    <message>
+        <location filename="../src/widgets/qstatwidget.ui" line="14"/>
+        <source>Statistics</source>
+        <translation>Статистика</translation>
     </message>
 </context>
 <context>
